diff --git a/exosphere/mariko_fatal/source/fatal_display.cpp b/exosphere/mariko_fatal/source/fatal_display.cpp
index da6575b..ad437e4 100644
--- a/exosphere/mariko_fatal/source/fatal_display.cpp
+++ b/exosphere/mariko_fatal/source/fatal_display.cpp
@@ -111,7 +111,7 @@
}
}
- void EnableBacklightForVendor2050ForHardwareTypeFive(int brightness) {
+ void EnableBacklightForVendor2050ForAula(int brightness) {
/* Enable FRAME_END_INT */
reg::Write(g_disp1_regs + sizeof(u32) * DC_CMD_INT_ENABLE, 2);
@@ -270,7 +270,7 @@
reg::ClearBits(g_apb_misc_regs + PINMUX_AUX_LCD_BL_EN, reg::EncodeMask(PINMUX_REG_BITS_MASK(AUX_TRISTATE)));
reg::ClearBits(g_apb_misc_regs + PINMUX_AUX_LCD_RST, reg::EncodeMask(PINMUX_REG_BITS_MASK(AUX_TRISTATE)));
- if (fuse::GetHardwareType() == fuse::HardwareType_Five) {
+ if (fuse::GetHardwareType() == fuse::HardwareType_Aula) {
/* Configure LCD backlight. */
reg::SetBits(g_gpio_regs + GPIO_PORT6_CNF_1, 0x4);
reg::SetBits(g_gpio_regs + GPIO_PORT6_OE_1, 0x4);
@@ -384,7 +384,7 @@
reg::ClearBits(g_apb_misc_regs + PINMUX_AUX_LCD_BL_EN, reg::EncodeMask(PINMUX_REG_BITS_MASK(AUX_TRISTATE)));
reg::ClearBits(g_apb_misc_regs + PINMUX_AUX_LCD_RST, reg::EncodeMask(PINMUX_REG_BITS_MASK(AUX_TRISTATE)));
- if (hw_type == fuse::HardwareType_Five) {
+ if (hw_type == fuse::HardwareType_Aula) {
/* Configure LCD backlight. */
reg::SetBits(g_gpio_regs + GPIO_PORT6_CNF_1, 0x4);
reg::SetBits(g_gpio_regs + GPIO_PORT6_OE_1, 0x4);
@@ -429,7 +429,7 @@
reg::SetBits(g_gpio_regs + GPIO_PORT6_OUT_1, 0x4);
util::WaitMicroSeconds(60'000ul);
- if (hw_type == fuse::HardwareType_Five) {
+ if (hw_type == fuse::HardwareType_Aula) {
reg::Write(g_dsi_regs + sizeof(u32) * DSI_BTA_TIMING, 0x40103);
} else {
reg::Write(g_dsi_regs + sizeof(u32) * DSI_BTA_TIMING, 0x50204);
@@ -593,7 +593,7 @@
/* Enable backlight. */
constexpr auto DisplayBrightness = 100;
if (GetLcdVendor() == 0x2050) {
- EnableBacklightForVendor2050ForHardwareTypeFive(DisplayBrightness);
+ EnableBacklightForVendor2050ForAula(DisplayBrightness);
} else {
EnableBacklightForGeneric(DisplayBrightness);
}
diff --git a/exosphere/program/source/smc/secmon_smc_info.cpp b/exosphere/program/source/smc/secmon_smc_info.cpp
index e7b52ed..468b134 100644
--- a/exosphere/program/source/smc/secmon_smc_info.cpp
+++ b/exosphere/program/source/smc/secmon_smc_info.cpp
@@ -47,7 +47,7 @@
[fuse::DramId_IcosaSamsung4GB] = pkg1::MemorySize_4GB,
[fuse::DramId_IcosaHynix4GB] = pkg1::MemorySize_4GB,
[fuse::DramId_IcosaMicron4GB] = pkg1::MemorySize_4GB,
- [fuse::DramId_FiveHynix1y4GB] = pkg1::MemorySize_4GB,
+ [fuse::DramId_AulaHynix1y4GB] = pkg1::MemorySize_4GB,
[fuse::DramId_IcosaSamsung6GB] = pkg1::MemorySize_6GB,
[fuse::DramId_CopperHynix4GB] = pkg1::MemorySize_4GB,
[fuse::DramId_CopperMicron4GB] = pkg1::MemorySize_4GB,
@@ -66,13 +66,13 @@
[fuse::DramId_HoagSamsung1y4GBX] = pkg1::MemorySize_4GB,
[fuse::DramId_IowaSamsung1y4GBY] = pkg1::MemorySize_4GB,
[fuse::DramId_IowaSamsung1y8GBY] = pkg1::MemorySize_8GB,
- [fuse::DramId_FiveSamsung1y4GB] = pkg1::MemorySize_4GB,
+ [fuse::DramId_AulaSamsung1y4GB] = pkg1::MemorySize_4GB,
[fuse::DramId_HoagSamsung1y8GBX] = pkg1::MemorySize_8GB,
- [fuse::DramId_FiveSamsung1y4GBX] = pkg1::MemorySize_4GB,
+ [fuse::DramId_AulaSamsung1y4GBX] = pkg1::MemorySize_4GB,
[fuse::DramId_IowaMicron1y4GB] = pkg1::MemorySize_4GB,
[fuse::DramId_HoagMicron1y4GB] = pkg1::MemorySize_4GB,
- [fuse::DramId_FiveMicron1y4GB] = pkg1::MemorySize_4GB,
- [fuse::DramId_FiveSamsung1y8GBX] = pkg1::MemorySize_8GB,
+ [fuse::DramId_AulaMicron1y4GB] = pkg1::MemorySize_4GB,
+ [fuse::DramId_AulaSamsung1y8GBX] = pkg1::MemorySize_8GB,
};
constexpr const pkg1::MemoryMode MemoryModes[] = {
diff --git a/libraries/libexosphere/include/exosphere/fuse.hpp b/libraries/libexosphere/include/exosphere/fuse.hpp
index c775610..cf8b54e 100644
--- a/libraries/libexosphere/include/exosphere/fuse.hpp
+++ b/libraries/libexosphere/include/exosphere/fuse.hpp
@@ -26,7 +26,7 @@
HardwareType_Hoag = 2,
HardwareType_Iowa = 3,
HardwareType_Calcio = 4,
- HardwareType_Five = 5,
+ HardwareType_Aula = 5,
HardwareType_Undefined = 0xF,
};
@@ -51,7 +51,7 @@
DramId_IcosaSamsung4GB = 0,
DramId_IcosaHynix4GB = 1,
DramId_IcosaMicron4GB = 2,
- DramId_FiveHynix1y4GB = 3,
+ DramId_AulaHynix1y4GB = 3,
DramId_IcosaSamsung6GB = 4,
DramId_CopperHynix4GB = 5,
DramId_CopperMicron4GB = 6,
@@ -70,13 +70,13 @@
DramId_HoagSamsung1y4GBX = 19,
DramId_IowaSamsung1y4GBY = 20,
DramId_IowaSamsung1y8GBY = 21,
- DramId_FiveSamsung1y4GB = 22,
+ DramId_AulaSamsung1y4GB = 22,
DramId_HoagSamsung1y8GBX = 23,
- DramId_FiveSamsung1y4GBX = 24,
+ DramId_AulaSamsung1y4GBX = 24,
DramId_IowaMicron1y4GB = 25,
DramId_HoagMicron1y4GB = 26,
- DramId_FiveMicron1y4GB = 27,
- DramId_FiveSamsung1y8GBX = 28,
+ DramId_AulaMicron1y4GB = 27,
+ DramId_AulaSamsung1y8GBX = 28,
DramId_Count,
};
diff --git a/libraries/libexosphere/source/fuse/fuse_api.cpp b/libraries/libexosphere/source/fuse/fuse_api.cpp
index 7e0b493..40047a9 100644
--- a/libraries/libexosphere/source/fuse/fuse_api.cpp
+++ b/libraries/libexosphere/source/fuse/fuse_api.cpp
@@ -316,7 +316,7 @@
case 0x02: return (true /* TODO: GetSocType() == SocType_Mariko */) ? HardwareType_Calcio : HardwareType_Copper;
case 0x04: return HardwareType_Iowa;
case 0x08: return HardwareType_Hoag;
- case 0x10: return HardwareType_Five;
+ case 0x10: return HardwareType_Aula;
default: return HardwareType_Undefined;
}
}
@@ -371,7 +371,7 @@
case HardwareType_Iowa:
case HardwareType_Hoag:
case HardwareType_Calcio:
- case HardwareType_Five:
+ case HardwareType_Aula:
return SocType_Mariko;
default:
return SocType_Undefined;
diff --git a/libraries/libstratosphere/include/stratosphere/spl/spl_types.hpp b/libraries/libstratosphere/include/stratosphere/spl/spl_types.hpp
index 1225cd6..3e1f2d7 100644
--- a/libraries/libstratosphere/include/stratosphere/spl/spl_types.hpp
+++ b/libraries/libstratosphere/include/stratosphere/spl/spl_types.hpp
@@ -106,12 +106,12 @@
}
enum class HardwareType {
- Icosa = 0,
- Copper = 1,
- Hoag = 2,
- Iowa = 3,
- Calcio = 4,
- _Five_ = 5,
+ Icosa = 0,
+ Copper = 1,
+ Hoag = 2,
+ Iowa = 3,
+ Calcio = 4,
+ Aula = 5,
};
enum SocType {
diff --git a/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config.cpp b/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config.cpp
index d229ea0..b6b1022 100644
--- a/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config.cpp
+++ b/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config.cpp
@@ -36,14 +36,14 @@
#include "gpio_initial_wake_pin_config_hoag.inc"
#include "gpio_initial_wake_pin_config_iowa.inc"
#include "gpio_initial_wake_pin_config_calcio.inc"
- #include "gpio_initial_wake_pin_config_five.inc"
+ #include "gpio_initial_wake_pin_config_aula.inc"
#include "gpio_initial_config_icosa.inc"
/* #include "gpio_initial_config_copper.inc" */
#include "gpio_initial_config_hoag.inc"
#include "gpio_initial_config_iowa.inc"
#include "gpio_initial_config_calcio.inc"
- #include "gpio_initial_config_five.inc"
+ #include "gpio_initial_config_aula.inc"
}
@@ -70,9 +70,9 @@
configs = InitialGpioConfigsCalcio;
num_configs = NumInitialGpioConfigsCalcio;
break;
- case spl::HardwareType::_Five_:
- configs = InitialGpioConfigsFive;
- num_configs = NumInitialGpioConfigsFive;
+ case spl::HardwareType::Aula:
+ configs = InitialGpioConfigsAula;
+ num_configs = NumInitialGpioConfigsAula;
break;
case spl::HardwareType::Copper:
AMS_UNREACHABLE_DEFAULT_CASE();
@@ -151,9 +151,9 @@
configs = InitialWakePinConfigsCalcio;
num_configs = NumInitialWakePinConfigsCalcio;
break;
- case spl::HardwareType::_Five_:
- configs = InitialWakePinConfigsFive;
- num_configs = NumInitialWakePinConfigsFive;
+ case spl::HardwareType::Aula:
+ configs = InitialWakePinConfigsAula;
+ num_configs = NumInitialWakePinConfigsAula;
break;
case spl::HardwareType::Copper:
AMS_UNREACHABLE_DEFAULT_CASE();
diff --git a/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config_aula.inc b/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config_aula.inc
new file mode 100644
index 0000000..e1c90ee
--- /dev/null
+++ b/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config_aula.inc
@@ -0,0 +1,70 @@
+/*
+ * Copyright (c) 2018-2020 Atmosphère-NX
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see .
+ */
+
+/* NOTE: This file is auto-generated by gpio_pad_gen.py, do not edit manually. */
+
+constexpr inline const GpioInitialConfig InitialGpioConfigsAula[] = {
+ { DeviceCode_GameCardReset, Direction_Output, GpioValue_Low },
+ { DeviceCode_CodecAlert, Direction_Input, GpioValue_Low },
+ { DeviceCode_Debug0, Direction_Output, GpioValue_Low },
+ { DeviceCode_Debug1, Direction_Output, GpioValue_Low },
+ { DeviceCode_Debug2, Direction_Output, GpioValue_Low },
+ { DeviceCode_Debug3, Direction_Output, GpioValue_Low },
+ { DeviceCode_PowSdEn, Direction_Output, GpioValue_Low },
+ { DeviceCode_ExtConWakeS, Direction_Input, GpioValue_Low },
+ { DeviceCode_GameCardCd, Direction_Input, GpioValue_High },
+ { DeviceCode_BattChgStatus, Direction_Input, GpioValue_Low },
+ { DeviceCode_BattChgEnableN, Direction_Output, GpioValue_Low },
+ { DeviceCode_FanTach, Direction_Input, GpioValue_Low },
+ { DeviceCode_Vdd50AEn, Direction_Output, GpioValue_Low },
+ { DeviceCode_Vdd5V3En, Direction_Output, GpioValue_Low },
+ { DeviceCode_TempAlert, Direction_Input, GpioValue_High },
+ { DeviceCode_MotionInt, Direction_Input, GpioValue_Low },
+ { DeviceCode_CodecHpDetIrq, Direction_Input, GpioValue_Low },
+ { DeviceCode_TpIrq, Direction_Input, GpioValue_High },
+ { DeviceCode_ButtonSleep2, Direction_Input, GpioValue_Low },
+ { DeviceCode_ButtonVolUp, Direction_Input, GpioValue_High },
+ { DeviceCode_ButtonVolDn, Direction_Input, GpioValue_High },
+ { DeviceCode_BattMgicIrq, Direction_Input, GpioValue_Low },
+ { DeviceCode_RecoveryKey, Direction_Input, GpioValue_Low },
+ { DeviceCode_LcdReset, Direction_Output, GpioValue_Low },
+ { DeviceCode_PdRstN, Direction_Output, GpioValue_Low },
+ { DeviceCode_Bq24190Irq, Direction_Input, GpioValue_Low },
+ { DeviceCode_SdCd, Direction_Input, GpioValue_High },
+ { DeviceCode_SdWp, Direction_Input, GpioValue_High },
+ { DeviceCode_CodecLdoEnTemp, Direction_Output, GpioValue_Low },
+ { DeviceCode_TpReset, Direction_Output, GpioValue_Low },
+ { DeviceCode_ExtconDetU, Direction_Input, GpioValue_Low },
+ { DeviceCode_BtGpio2, Direction_Input, GpioValue_Low },
+ { DeviceCode_BtGpio3, Direction_Input, GpioValue_Low },
+ { DeviceCode_BtGpio4, Direction_Input, GpioValue_Low },
+ { DeviceCode_ExtconChgU, Direction_Output, GpioValue_Low },
+ { DeviceCode_CradleIrq, Direction_Input, GpioValue_High },
+ { DeviceCode_PdVconnEn, Direction_Output, GpioValue_Low },
+ { DeviceCode_PowVcpuInt, Direction_Input, GpioValue_High },
+ { DeviceCode_ExtconDetS, Direction_Input, GpioValue_Low },
+ { DeviceCode_GpioPortH0, Direction_Input, GpioValue_Low },
+ { DeviceCode_WifiReset, Direction_Output, GpioValue_Low },
+ { DeviceCode_WifiWakeHost, Direction_Input, GpioValue_Low },
+ { DeviceCode_ApWakeBt, Direction_Output, GpioValue_Low },
+ { DeviceCode_BtRst, Direction_Output, GpioValue_Low },
+ { DeviceCode_BtWakeAp, Direction_Input, GpioValue_Low },
+ { DeviceCode_ExtConWakeU, Direction_Input, GpioValue_Low },
+ { DeviceCode_BtGpio5, Direction_Output, GpioValue_Low },
+ { DeviceCode_ExtconChgS, Direction_Output, GpioValue_Low },
+};
+
+constexpr inline size_t NumInitialGpioConfigsAula = util::size(InitialGpioConfigsAula);
diff --git a/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config_five.inc b/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config_five.inc
deleted file mode 100644
index bc86cb9..0000000
--- a/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_config_five.inc
+++ /dev/null
@@ -1,70 +0,0 @@
-/*
- * Copyright (c) 2018-2020 Atmosphère-NX
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU General Public License,
- * version 2, as published by the Free Software Foundation.
- *
- * This program is distributed in the hope it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see .
- */
-
-/* NOTE: This file is auto-generated by gpio_pad_gen.py, do not edit manually. */
-
-constexpr inline const GpioInitialConfig InitialGpioConfigsFive[] = {
- { DeviceCode_GameCardReset, Direction_Output, GpioValue_Low },
- { DeviceCode_CodecAlert, Direction_Input, GpioValue_Low },
- { DeviceCode_Debug0, Direction_Output, GpioValue_Low },
- { DeviceCode_Debug1, Direction_Output, GpioValue_Low },
- { DeviceCode_Debug2, Direction_Output, GpioValue_Low },
- { DeviceCode_Debug3, Direction_Output, GpioValue_Low },
- { DeviceCode_PowSdEn, Direction_Output, GpioValue_Low },
- { DeviceCode_ExtConWakeS, Direction_Input, GpioValue_Low },
- { DeviceCode_GameCardCd, Direction_Input, GpioValue_High },
- { DeviceCode_BattChgStatus, Direction_Input, GpioValue_Low },
- { DeviceCode_BattChgEnableN, Direction_Output, GpioValue_Low },
- { DeviceCode_FanTach, Direction_Input, GpioValue_Low },
- { DeviceCode_Vdd50AEn, Direction_Output, GpioValue_Low },
- { DeviceCode_Vdd5V3En, Direction_Output, GpioValue_Low },
- { DeviceCode_TempAlert, Direction_Input, GpioValue_High },
- { DeviceCode_MotionInt, Direction_Input, GpioValue_Low },
- { DeviceCode_CodecHpDetIrq, Direction_Input, GpioValue_Low },
- { DeviceCode_TpIrq, Direction_Input, GpioValue_High },
- { DeviceCode_ButtonSleep2, Direction_Input, GpioValue_Low },
- { DeviceCode_ButtonVolUp, Direction_Input, GpioValue_High },
- { DeviceCode_ButtonVolDn, Direction_Input, GpioValue_High },
- { DeviceCode_BattMgicIrq, Direction_Input, GpioValue_Low },
- { DeviceCode_RecoveryKey, Direction_Input, GpioValue_Low },
- { DeviceCode_LcdReset, Direction_Output, GpioValue_Low },
- { DeviceCode_PdRstN, Direction_Output, GpioValue_Low },
- { DeviceCode_Bq24190Irq, Direction_Input, GpioValue_Low },
- { DeviceCode_SdCd, Direction_Input, GpioValue_High },
- { DeviceCode_SdWp, Direction_Input, GpioValue_High },
- { DeviceCode_CodecLdoEnTemp, Direction_Output, GpioValue_Low },
- { DeviceCode_TpReset, Direction_Output, GpioValue_Low },
- { DeviceCode_ExtconDetU, Direction_Input, GpioValue_Low },
- { DeviceCode_BtGpio2, Direction_Input, GpioValue_Low },
- { DeviceCode_BtGpio3, Direction_Input, GpioValue_Low },
- { DeviceCode_BtGpio4, Direction_Input, GpioValue_Low },
- { DeviceCode_ExtconChgU, Direction_Output, GpioValue_Low },
- { DeviceCode_CradleIrq, Direction_Input, GpioValue_High },
- { DeviceCode_PdVconnEn, Direction_Output, GpioValue_Low },
- { DeviceCode_PowVcpuInt, Direction_Input, GpioValue_High },
- { DeviceCode_ExtconDetS, Direction_Input, GpioValue_Low },
- { DeviceCode_GpioPortH0, Direction_Input, GpioValue_Low },
- { DeviceCode_WifiReset, Direction_Output, GpioValue_Low },
- { DeviceCode_WifiWakeHost, Direction_Input, GpioValue_Low },
- { DeviceCode_ApWakeBt, Direction_Output, GpioValue_Low },
- { DeviceCode_BtRst, Direction_Output, GpioValue_Low },
- { DeviceCode_BtWakeAp, Direction_Input, GpioValue_Low },
- { DeviceCode_ExtConWakeU, Direction_Input, GpioValue_Low },
- { DeviceCode_BtGpio5, Direction_Output, GpioValue_Low },
- { DeviceCode_ExtconChgS, Direction_Output, GpioValue_Low },
-};
-
-constexpr inline size_t NumInitialGpioConfigsFive = util::size(InitialGpioConfigsFive);
diff --git a/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_wake_pin_config_aula.inc b/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_wake_pin_config_aula.inc
new file mode 100644
index 0000000..d955382
--- /dev/null
+++ b/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_wake_pin_config_aula.inc
@@ -0,0 +1,80 @@
+/*
+ * Copyright (c) 2018-2020 Atmosphère-NX
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see .
+ */
+
+/* NOTE: This file is auto-generated by wake_pin_gen.py, do not edit manually. */
+
+constexpr inline const WakePinConfig InitialWakePinConfigsAula[] = {
+ { ams::wec::WakeEvent_PexWakeN, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_GpioPortA6, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_QspiCsN, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Spi2Mosi, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_ExtconDetS, true, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_McuIrq, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Uart2Cts, true, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Uart3Cts, true, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_WifiWakeAp, true, ams::wec::WakeEventLevel_High },
+ /* { ams::wec::WakeEvent_AoTag2Pmc, }, */
+ { ams::wec::WakeEvent_ExtconDetU, true, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_NfcInt, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Gen1I2cSda, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Gen2I2cSda, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_CradleIrq, true, ams::wec::WakeEventLevel_Low },
+ { ams::wec::WakeEvent_GpioPortK6, false, ams::wec::WakeEventLevel_Auto },
+ /* { ams::wec::WakeEvent_RtcIrq, }, */
+ { ams::wec::WakeEvent_Sdmmc1Dat1, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Sdmmc2Dat1, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_HdmiCec, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Gen3I2cSda, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_GpioPortL1, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Clk_32kOut, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_PwrI2cSda, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_ButtonPowerOn, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_ButtonVolUp, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_ButtonVolDown, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_ButtonSlideSw, true, ams::wec::WakeEventLevel_Low },
+ { ams::wec::WakeEvent_ButtonHome, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_AlsProxInt, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_TempAlert, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Bq24190Irq, true, ams::wec::WakeEventLevel_Low },
+ { ams::wec::WakeEvent_SdCd, true, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_GpioPortZ2, false, ams::wec::WakeEventLevel_Auto },
+ /* { ams::wec::WakeEvent_Utmip0, }, */
+ /* { ams::wec::WakeEvent_Utmip1, }, */
+ /* { ams::wec::WakeEvent_Utmip2, }, */
+ /* { ams::wec::WakeEvent_Utmip3, }, */
+ /* { ams::wec::WakeEvent_Uhsic, }, */
+ /* { ams::wec::WakeEvent_Wake2PmcXusbSystem, }, */
+ { ams::wec::WakeEvent_Sdmmc3Dat1, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Sdmmc4Dat1, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_CamI2cScl, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_CamI2cSda, true, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_GpioPortZ5, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_DpHpd0, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_PwrIntN, true, ams::wec::WakeEventLevel_Low },
+ { ams::wec::WakeEvent_BtWakeAp, true, ams::wec::WakeEventLevel_Low },
+ { ams::wec::WakeEvent_HdmiIntDpHpd, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_UsbVbusEn0, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_UsbVbusEn1, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_LcdRst, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_LcdGpio1, false, ams::wec::WakeEventLevel_Low },
+ { ams::wec::WakeEvent_LcdGpio2, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_Uart4Cts, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_ModemWakeAp, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_TouchInt, false, ams::wec::WakeEventLevel_Auto },
+ { ams::wec::WakeEvent_MotionInt, false, ams::wec::WakeEventLevel_Auto },
+};
+
+constexpr inline size_t NumInitialWakePinConfigsAula = util::size(InitialWakePinConfigsAula);
diff --git a/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_wake_pin_config_five.inc b/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_wake_pin_config_five.inc
deleted file mode 100644
index 809cbf5..0000000
--- a/libraries/libstratosphere/source/gpio/driver/board/nintendo_nx/impl/gpio_initial_wake_pin_config_five.inc
+++ /dev/null
@@ -1,80 +0,0 @@
-/*
- * Copyright (c) 2018-2020 Atmosphère-NX
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU General Public License,
- * version 2, as published by the Free Software Foundation.
- *
- * This program is distributed in the hope it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see .
- */
-
-/* NOTE: This file is auto-generated by wake_pin_gen.py, do not edit manually. */
-
-constexpr inline const WakePinConfig InitialWakePinConfigsFive[] = {
- { ams::wec::WakeEvent_PexWakeN, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_GpioPortA6, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_QspiCsN, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Spi2Mosi, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_ExtconDetS, true, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_McuIrq, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Uart2Cts, true, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Uart3Cts, true, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_WifiWakeAp, true, ams::wec::WakeEventLevel_High },
- /* { ams::wec::WakeEvent_AoTag2Pmc, }, */
- { ams::wec::WakeEvent_ExtconDetU, true, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_NfcInt, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Gen1I2cSda, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Gen2I2cSda, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_CradleIrq, true, ams::wec::WakeEventLevel_Low },
- { ams::wec::WakeEvent_GpioPortK6, false, ams::wec::WakeEventLevel_Auto },
- /* { ams::wec::WakeEvent_RtcIrq, }, */
- { ams::wec::WakeEvent_Sdmmc1Dat1, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Sdmmc2Dat1, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_HdmiCec, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Gen3I2cSda, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_GpioPortL1, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Clk_32kOut, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_PwrI2cSda, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_ButtonPowerOn, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_ButtonVolUp, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_ButtonVolDown, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_ButtonSlideSw, true, ams::wec::WakeEventLevel_Low },
- { ams::wec::WakeEvent_ButtonHome, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_AlsProxInt, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_TempAlert, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Bq24190Irq, true, ams::wec::WakeEventLevel_Low },
- { ams::wec::WakeEvent_SdCd, true, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_GpioPortZ2, false, ams::wec::WakeEventLevel_Auto },
- /* { ams::wec::WakeEvent_Utmip0, }, */
- /* { ams::wec::WakeEvent_Utmip1, }, */
- /* { ams::wec::WakeEvent_Utmip2, }, */
- /* { ams::wec::WakeEvent_Utmip3, }, */
- /* { ams::wec::WakeEvent_Uhsic, }, */
- /* { ams::wec::WakeEvent_Wake2PmcXusbSystem, }, */
- { ams::wec::WakeEvent_Sdmmc3Dat1, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Sdmmc4Dat1, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_CamI2cScl, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_CamI2cSda, true, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_GpioPortZ5, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_DpHpd0, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_PwrIntN, true, ams::wec::WakeEventLevel_Low },
- { ams::wec::WakeEvent_BtWakeAp, true, ams::wec::WakeEventLevel_Low },
- { ams::wec::WakeEvent_HdmiIntDpHpd, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_UsbVbusEn0, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_UsbVbusEn1, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_LcdRst, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_LcdGpio1, false, ams::wec::WakeEventLevel_Low },
- { ams::wec::WakeEvent_LcdGpio2, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_Uart4Cts, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_ModemWakeAp, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_TouchInt, false, ams::wec::WakeEventLevel_Auto },
- { ams::wec::WakeEvent_MotionInt, false, ams::wec::WakeEventLevel_Auto },
-};
-
-constexpr inline size_t NumInitialWakePinConfigsFive = util::size(InitialWakePinConfigsFive);
diff --git a/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_board_driver_api.cpp b/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_board_driver_api.cpp
index fabedbb..fc35ce9 100644
--- a/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_board_driver_api.cpp
+++ b/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_board_driver_api.cpp
@@ -28,7 +28,7 @@
#include "pinmux_initial_pad_config_hoag.inc"
#include "pinmux_initial_pad_config_iowa.inc"
#include "pinmux_initial_pad_config_calcio.inc"
- #include "pinmux_initial_pad_config_five.inc"
+ #include "pinmux_initial_pad_config_aula.inc"
#include "pinmux_initial_drive_pad_config.inc"
#include "pinmux_initial_drive_pad_config_hoag.inc"
@@ -73,9 +73,9 @@
num_configs = NumPinmuxPadConfigsCalcio;
is_mariko = true;
break;
- case spl::HardwareType::_Five_:
- configs = PinmuxPadConfigsFive;
- num_configs = NumPinmuxPadConfigsFive;
+ case spl::HardwareType::Aula:
+ configs = PinmuxPadConfigsAula;
+ num_configs = NumPinmuxPadConfigsAula;
is_mariko = true;
break;
AMS_UNREACHABLE_DEFAULT_CASE();
@@ -121,7 +121,7 @@
configs = PinmuxDrivePadConfigs;
num_configs = NumPinmuxDrivePadConfigs;
break;
- case spl::HardwareType::_Five_:
+ case spl::HardwareType::Aula:
configs = PinmuxDrivePadConfigs;
num_configs = NumPinmuxDrivePadConfigs;
break;
diff --git a/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_initial_pad_config_aula.inc b/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_initial_pad_config_aula.inc
new file mode 100644
index 0000000..14bcc76
--- /dev/null
+++ b/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_initial_pad_config_aula.inc
@@ -0,0 +1,196 @@
+/*
+ * Copyright (c) 2018-2020 Atmosphère-NX
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see .
+ */
+
+/* NOTE: This file is auto-generated by pinmux_initial_config.py, do not edit manually. */
+
+constexpr inline const PinmuxPadConfig PinmuxPadConfigsAula[] = {
+{ PinmuxPadIndex_AudMclk, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Dap1Din, 0x00000028, 0x0000007F },
+{ PinmuxPadIndex_Dap1Dout, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Dap1Fs, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Dap1Sclk, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Gen3I2cScl, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_Gen3I2cSda, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_PexL0ClkreqN, 0x00000020, 0x0000027F },
+{ PinmuxPadIndex_PexL0RstN, 0x00000000, 0x0000027F },
+{ PinmuxPadIndex_PexL1ClkreqN, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_PexL1RstN, 0x00000000, 0x0000027F },
+{ PinmuxPadIndex_PexWakeN, 0x00000020, 0x0000027F },
+{ PinmuxPadIndex_Sdmmc1Clk, 0x00000040, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc1Cmd, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc1Dat0, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc1Dat1, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc1Dat2, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc1Dat3, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Clk, 0x00000040, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Cmd, 0x00000040, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Dat0, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Dat1, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Dat2, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Dat3, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Dat4, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Dat5, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Dat6, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Sdmmc2Dat7, 0x00000050, 0x0000007F },
+{ PinmuxPadIndex_Shutdown, 0x00000000, 0x00000078 },
+{ PinmuxPadIndex_LcdGpio2, 0x00000001, 0x0000007F },
+{ PinmuxPadIndex_PwrI2cScl, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_PwrI2cSda, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_Clk32kIn, 0x00000020, 0x00000078 },
+{ PinmuxPadIndex_Clk32kOut, 0x00000020, 0x0000007F },
+{ PinmuxPadIndex_CorePwrReq, 0x00000000, 0x00000078 },
+{ PinmuxPadIndex_PwrIntN, 0x00000020, 0x00000078 },
+{ PinmuxPadIndex_Gen1I2cScl, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_Gen1I2cSda, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_Gen2I2cScl, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_Gen2I2cSda, 0x00000040, 0x0000027F },
+{ PinmuxPadIndex_Uart2Rx, 0x00000020, 0x0000007F },
+{ PinmuxPadIndex_Uart2Rts, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Uart2Cts, 0x00000020, 0x0000007F },
+{ PinmuxPadIndex_Uart1Tx, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Uart1Rx, 0x00000030, 0x0000007F },
+{ PinmuxPadIndex_Uart1Rts, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Uart1Cts, 0x00000028, 0x0000007F },
+{ PinmuxPadIndex_JtagRtck, 0x00000000, 0x00000067 },
+{ PinmuxPadIndex_GpioPl1, 0x00000030, 0x0000007F },
+{ PinmuxPadIndex_Spi4Mosi, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Spi4Miso, 0x00000030, 0x0000007F },
+{ PinmuxPadIndex_Spi4Sck, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Spi4Cs0, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Uart3Rx, 0x00000020, 0x0000007F },
+{ PinmuxPadIndex_Uart3Rts, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Uart3Cts, 0x00000030, 0x0000007F },
+{ PinmuxPadIndex_Uart4Tx, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Uart4Rx, 0x00000028, 0x0000007F },
+{ PinmuxPadIndex_Uart4Rts, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Uart4Cts, 0x00000028, 0x0000007F },
+{ PinmuxPadIndex_Dap2Din, 0x00000028, 0x0000007F },
+{ PinmuxPadIndex_Dap2Dout, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Dap2Fs, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_Dap2Sclk, 0x00000000, 0x0000007F },
+{ PinmuxPadIndex_HdmiIntDpHpd, 0x00000020, 0x0000027F },
+{ PinmuxPadIndex_GpioX1Aud, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_GpioX3Aud, 0x0000002C, 0x0000007F },
+{ PinmuxPadIndex_Dmic1Clk, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_Dmic1Dat, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_Dmic2Clk, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_Dmic2Dat, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_Dmic3Clk, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_GpioPe6, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_CamI2cSda, 0x00000034, 0x0000027F },
+{ PinmuxPadIndex_Cam2Mclk, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_CamFlashEn, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_Cam1Pwdn, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_SataLedActive, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_AlsProxInt, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_TempAlert, 0x00000034, 0x0000007F },
+{ PinmuxPadIndex_MotionInt, 0x0000002C, 0x0000007F },
+{ PinmuxPadIndex_TouchRst, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_TouchInt, 0x00000034, 0x0000007F },
+{ PinmuxPadIndex_ButtonPowerOn, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_ButtonVolUp, 0x00000034, 0x0000007F },
+{ PinmuxPadIndex_ButtonVolDown, 0x00000034, 0x0000007F },
+{ PinmuxPadIndex_ButtonSlideSw, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_ButtonHome, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_LcdRst, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_ApReady, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_GpioPz0, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_GpioPz1, 0x00000034, 0x0000007F },
+{ PinmuxPadIndex_GpioPz3, 0x00000034, 0x0000007F },
+{ PinmuxPadIndex_GpioPz4, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_Dap4Sclk, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_Uart2Tx, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_GpioPk0, 0x0000004C, 0x0000007F },
+{ PinmuxPadIndex_GpioPk1, 0x0000004C, 0x0000007F },
+{ PinmuxPadIndex_GpioPk2, 0x00000044, 0x0000007F },
+{ PinmuxPadIndex_GpioPk3, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_GpioPk4, 0x00000034, 0x0000007F },
+{ PinmuxPadIndex_GpioPk5, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_GpioPk6, 0x00000034, 0x0000007F },
+{ PinmuxPadIndex_Uart3Tx, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_WifiEn, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_WifiRst, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_WifiWakeAp, 0x0000002C, 0x0000007F },
+{ PinmuxPadIndex_ApWakeBt, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_BtRst, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_BtWakeAp, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_GpioPh6, 0x00000024, 0x0000007F },
+{ PinmuxPadIndex_ApWakeNfc, 0x00000004, 0x0000007F },
+{ PinmuxPadIndex_SpdifIn, 0x00000004, 0x00000067 },
+{ PinmuxPadIndex_DvfsPwm, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_DvfsClk, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi2Mosi, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi2Miso, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi2Sck, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi2Cs0, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi2Cs1, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Dmic3Dat, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpioPe7, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_CamI2cScl, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Cam1Mclk, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_CamRst, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_CamAfEn, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Cam2Pwdn, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Cam1Strobe, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpioPa6, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc2Clkb, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc2Dqs, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc2Dqsb, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc3Clk, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc3Cmd, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc3Dat0, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc3Dat1, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc3Dat2, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Sdmmc3Dat3, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_TouchClk, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_ModemWakeAp, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_LcdTe, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_LcdBlPwm, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_LcdBlEn, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_LcdGpio1, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpioPz2, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpioPz5, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_ClkReq, 0x00000000, 0x00000000 },
+{ PinmuxPadIndex_CpuPwrReq, 0x00000000, 0x00000000 },
+{ PinmuxPadIndex_Dap4Din, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Dap4Dout, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Dap4Fs, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpioPk7, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpioPl0, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi1Mosi, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi1Miso, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi1Sck, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi1Cs0, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_Spi1Cs1, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_NfcEn, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_NfcInt, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpsEn, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpsRst, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_QspiIo0, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_QspiIo1, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_QspiSck, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_QspiCsN, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_QspiIo2, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_QspiIo3, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_GpioPcc7, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_SpdifOut, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_UsbVbusEn0, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_UsbVbusEn1, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_DpHpd0, 0x00000005, 0x00000007 },
+{ PinmuxPadIndex_HdmiCec, 0x00000005, 0x00000007 },
+};
+
+constexpr inline const size_t NumPinmuxPadConfigsAula = util::size(PinmuxPadConfigsAula);
diff --git a/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_initial_pad_config_five.inc b/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_initial_pad_config_five.inc
deleted file mode 100644
index 0279136..0000000
--- a/libraries/libstratosphere/source/pinmux/driver/board/nintendo_nx/pinmux_initial_pad_config_five.inc
+++ /dev/null
@@ -1,196 +0,0 @@
-/*
- * Copyright (c) 2018-2020 Atmosphère-NX
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU General Public License,
- * version 2, as published by the Free Software Foundation.
- *
- * This program is distributed in the hope it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see .
- */
-
-/* NOTE: This file is auto-generated by pinmux_initial_config.py, do not edit manually. */
-
-constexpr inline const PinmuxPadConfig PinmuxPadConfigsFive[] = {
-{ PinmuxPadIndex_AudMclk, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Dap1Din, 0x00000028, 0x0000007F },
-{ PinmuxPadIndex_Dap1Dout, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Dap1Fs, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Dap1Sclk, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Gen3I2cScl, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_Gen3I2cSda, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_PexL0ClkreqN, 0x00000020, 0x0000027F },
-{ PinmuxPadIndex_PexL0RstN, 0x00000000, 0x0000027F },
-{ PinmuxPadIndex_PexL1ClkreqN, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_PexL1RstN, 0x00000000, 0x0000027F },
-{ PinmuxPadIndex_PexWakeN, 0x00000020, 0x0000027F },
-{ PinmuxPadIndex_Sdmmc1Clk, 0x00000040, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc1Cmd, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc1Dat0, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc1Dat1, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc1Dat2, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc1Dat3, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Clk, 0x00000040, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Cmd, 0x00000040, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Dat0, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Dat1, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Dat2, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Dat3, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Dat4, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Dat5, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Dat6, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Sdmmc2Dat7, 0x00000050, 0x0000007F },
-{ PinmuxPadIndex_Shutdown, 0x00000000, 0x00000078 },
-{ PinmuxPadIndex_LcdGpio2, 0x00000001, 0x0000007F },
-{ PinmuxPadIndex_PwrI2cScl, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_PwrI2cSda, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_Clk32kIn, 0x00000020, 0x00000078 },
-{ PinmuxPadIndex_Clk32kOut, 0x00000020, 0x0000007F },
-{ PinmuxPadIndex_CorePwrReq, 0x00000000, 0x00000078 },
-{ PinmuxPadIndex_PwrIntN, 0x00000020, 0x00000078 },
-{ PinmuxPadIndex_Gen1I2cScl, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_Gen1I2cSda, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_Gen2I2cScl, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_Gen2I2cSda, 0x00000040, 0x0000027F },
-{ PinmuxPadIndex_Uart2Rx, 0x00000020, 0x0000007F },
-{ PinmuxPadIndex_Uart2Rts, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Uart2Cts, 0x00000020, 0x0000007F },
-{ PinmuxPadIndex_Uart1Tx, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Uart1Rx, 0x00000030, 0x0000007F },
-{ PinmuxPadIndex_Uart1Rts, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Uart1Cts, 0x00000028, 0x0000007F },
-{ PinmuxPadIndex_JtagRtck, 0x00000000, 0x00000067 },
-{ PinmuxPadIndex_GpioPl1, 0x00000030, 0x0000007F },
-{ PinmuxPadIndex_Spi4Mosi, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Spi4Miso, 0x00000030, 0x0000007F },
-{ PinmuxPadIndex_Spi4Sck, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Spi4Cs0, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Uart3Rx, 0x00000020, 0x0000007F },
-{ PinmuxPadIndex_Uart3Rts, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Uart3Cts, 0x00000030, 0x0000007F },
-{ PinmuxPadIndex_Uart4Tx, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Uart4Rx, 0x00000028, 0x0000007F },
-{ PinmuxPadIndex_Uart4Rts, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Uart4Cts, 0x00000028, 0x0000007F },
-{ PinmuxPadIndex_Dap2Din, 0x00000028, 0x0000007F },
-{ PinmuxPadIndex_Dap2Dout, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Dap2Fs, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_Dap2Sclk, 0x00000000, 0x0000007F },
-{ PinmuxPadIndex_HdmiIntDpHpd, 0x00000020, 0x0000027F },
-{ PinmuxPadIndex_GpioX1Aud, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_GpioX3Aud, 0x0000002C, 0x0000007F },
-{ PinmuxPadIndex_Dmic1Clk, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_Dmic1Dat, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_Dmic2Clk, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_Dmic2Dat, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_Dmic3Clk, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_GpioPe6, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_CamI2cSda, 0x00000034, 0x0000027F },
-{ PinmuxPadIndex_Cam2Mclk, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_CamFlashEn, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_Cam1Pwdn, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_SataLedActive, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_AlsProxInt, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_TempAlert, 0x00000034, 0x0000007F },
-{ PinmuxPadIndex_MotionInt, 0x0000002C, 0x0000007F },
-{ PinmuxPadIndex_TouchRst, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_TouchInt, 0x00000034, 0x0000007F },
-{ PinmuxPadIndex_ButtonPowerOn, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_ButtonVolUp, 0x00000034, 0x0000007F },
-{ PinmuxPadIndex_ButtonVolDown, 0x00000034, 0x0000007F },
-{ PinmuxPadIndex_ButtonSlideSw, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_ButtonHome, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_LcdRst, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_ApReady, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_GpioPz0, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_GpioPz1, 0x00000034, 0x0000007F },
-{ PinmuxPadIndex_GpioPz3, 0x00000034, 0x0000007F },
-{ PinmuxPadIndex_GpioPz4, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_Dap4Sclk, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_Uart2Tx, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_GpioPk0, 0x0000004C, 0x0000007F },
-{ PinmuxPadIndex_GpioPk1, 0x0000004C, 0x0000007F },
-{ PinmuxPadIndex_GpioPk2, 0x00000044, 0x0000007F },
-{ PinmuxPadIndex_GpioPk3, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_GpioPk4, 0x00000034, 0x0000007F },
-{ PinmuxPadIndex_GpioPk5, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_GpioPk6, 0x00000034, 0x0000007F },
-{ PinmuxPadIndex_Uart3Tx, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_WifiEn, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_WifiRst, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_WifiWakeAp, 0x0000002C, 0x0000007F },
-{ PinmuxPadIndex_ApWakeBt, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_BtRst, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_BtWakeAp, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_GpioPh6, 0x00000024, 0x0000007F },
-{ PinmuxPadIndex_ApWakeNfc, 0x00000004, 0x0000007F },
-{ PinmuxPadIndex_SpdifIn, 0x00000004, 0x00000067 },
-{ PinmuxPadIndex_DvfsPwm, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_DvfsClk, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi2Mosi, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi2Miso, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi2Sck, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi2Cs0, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi2Cs1, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Dmic3Dat, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpioPe7, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_CamI2cScl, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Cam1Mclk, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_CamRst, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_CamAfEn, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Cam2Pwdn, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Cam1Strobe, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpioPa6, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc2Clkb, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc2Dqs, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc2Dqsb, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc3Clk, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc3Cmd, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc3Dat0, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc3Dat1, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc3Dat2, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Sdmmc3Dat3, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_TouchClk, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_ModemWakeAp, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_LcdTe, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_LcdBlPwm, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_LcdBlEn, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_LcdGpio1, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpioPz2, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpioPz5, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_ClkReq, 0x00000000, 0x00000000 },
-{ PinmuxPadIndex_CpuPwrReq, 0x00000000, 0x00000000 },
-{ PinmuxPadIndex_Dap4Din, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Dap4Dout, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Dap4Fs, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpioPk7, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpioPl0, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi1Mosi, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi1Miso, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi1Sck, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi1Cs0, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_Spi1Cs1, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_NfcEn, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_NfcInt, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpsEn, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpsRst, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_QspiIo0, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_QspiIo1, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_QspiSck, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_QspiCsN, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_QspiIo2, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_QspiIo3, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_GpioPcc7, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_SpdifOut, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_UsbVbusEn0, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_UsbVbusEn1, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_DpHpd0, 0x00000005, 0x00000007 },
-{ PinmuxPadIndex_HdmiCec, 0x00000005, 0x00000007 },
-};
-
-constexpr inline const size_t NumPinmuxPadConfigsFive = util::size(PinmuxPadConfigsFive);
diff --git a/libraries/libstratosphere/source/powctl/driver/impl/powctl_charger_parameters.board.nintendo_nx.cpp b/libraries/libstratosphere/source/powctl/driver/impl/powctl_charger_parameters.board.nintendo_nx.cpp
index aa49183..6c38cba 100644
--- a/libraries/libstratosphere/source/powctl/driver/impl/powctl_charger_parameters.board.nintendo_nx.cpp
+++ b/libraries/libstratosphere/source/powctl/driver/impl/powctl_charger_parameters.board.nintendo_nx.cpp
@@ -63,8 +63,8 @@
} else if (battery_version == 1) {
return ChargeParametersForBatteryVersion1;
} else {
- if (spl::GetHardwareType() == spl::HardwareType::_Five_) {
- return ChargeParametersForBatteryVersion0ForFive;
+ if (spl::GetHardwareType() == spl::HardwareType::Aula) {
+ return ChargeParametersForBatteryVersion0ForAula;
} else {
return ChargeParametersForBatteryVersion0;
}
diff --git a/libraries/libstratosphere/source/powctl/driver/impl/powctl_charger_parameters.board.nintendo_nx.inc b/libraries/libstratosphere/source/powctl/driver/impl/powctl_charger_parameters.board.nintendo_nx.inc
index 70f86ac..a88f5f4 100644
--- a/libraries/libstratosphere/source/powctl/driver/impl/powctl_charger_parameters.board.nintendo_nx.inc
+++ b/libraries/libstratosphere/source/powctl/driver/impl/powctl_charger_parameters.board.nintendo_nx.inc
@@ -51,7 +51,7 @@
{ BatteryTemperatureLevel::TooHigh, 4080, Max, Min, Max, Min, Max, AcceptablePowerStates, util::size(AcceptablePowerStates), false, false, 4320, 1664, 0, 0 },
};
-constexpr inline const ChargeParametersRule ChargeParametersRulesForBatteryVersion0ForFive[] = {
+constexpr inline const ChargeParametersRule ChargeParametersRulesForBatteryVersion0ForAula[] = {
{ BatteryTemperatureLevel::TooLow, Min, Max, Min, Max, Min, Max, AcceptablePowerStates, util::size(AcceptablePowerStates), false, false, 4208, 768, 0, 0 },
{ BatteryTemperatureLevel::Low, Min, Max, Min, Max, Min, Max, AcceptablePowerStates, util::size(AcceptablePowerStates), false, true, 4208, 768, 0, 0 },
{ BatteryTemperatureLevel::Medium, Min, Max, Min, 4001, 2049, Max, AcceptablePowerStatesForNotAwakeCharge, util::size(AcceptablePowerStatesForNotAwakeCharge), true, true, 4000, 3072, 40, 112 },
@@ -74,6 +74,6 @@
1, 19, 48, 59, 1664, 4320, UnknownXTableForBatteryVersion2, util::size(UnknownXTableForBatteryVersion2), 95.0, 100.4, ChargeParametersRulesForBatteryVersion2, util::size(ChargeParametersRulesForBatteryVersion2)
};
-constexpr inline const ChargeParameters ChargeParametersForBatteryVersion0ForFive = {
- 4, 17, 51, 60, 512, 4208, nullptr, 0, 95.0, 99.0, ChargeParametersRulesForBatteryVersion0ForFive, util::size(ChargeParametersRulesForBatteryVersion0ForFive)
+constexpr inline const ChargeParameters ChargeParametersForBatteryVersion0ForAula = {
+ 4, 17, 51, 60, 512, 4208, nullptr, 0, 95.0, 99.0, ChargeParametersRulesForBatteryVersion0ForAula, util::size(ChargeParametersRulesForBatteryVersion0ForAula)
};
diff --git a/libraries/libstratosphere/source/spl/spl_api.cpp b/libraries/libstratosphere/source/spl/spl_api.cpp
index ed5de78..721ff7d 100644
--- a/libraries/libstratosphere/source/spl/spl_api.cpp
+++ b/libraries/libstratosphere/source/spl/spl_api.cpp
@@ -254,7 +254,7 @@
return SocType_Erista;
case HardwareType::Hoag:
case HardwareType::Iowa:
- case HardwareType::_Five_:
+ case HardwareType::Aula:
return SocType_Mariko;
AMS_UNREACHABLE_DEFAULT_CASE();
}
diff --git a/libraries/libstratosphere/source/updater/updater_api.cpp b/libraries/libstratosphere/source/updater/updater_api.cpp
index 124cee5..00071b8 100644
--- a/libraries/libstratosphere/source/updater/updater_api.cpp
+++ b/libraries/libstratosphere/source/updater/updater_api.cpp
@@ -464,7 +464,7 @@
case spl::HardwareType::Hoag:
case spl::HardwareType::Iowa:
case spl::HardwareType::Calcio:
- case spl::HardwareType::_Five_:
+ case spl::HardwareType::Aula:
return BootImageUpdateType::Mariko;
AMS_UNREACHABLE_DEFAULT_CASE();
}
diff --git a/stratosphere/boot/source/boot_display.cpp b/stratosphere/boot/source/boot_display.cpp
index 9509162..4a7fb87 100644
--- a/stratosphere/boot/source/boot_display.cpp
+++ b/stratosphere/boot/source/boot_display.cpp
@@ -203,7 +203,7 @@
}
}
- void EnableBacklightForVendor2050ForHardwareTypeFive(int brightness) {
+ void EnableBacklightForVendor2050ForAula(int brightness) {
/* Enable FRAME_END_INT */
reg::Write(g_disp1_regs + sizeof(u32) * DC_CMD_INT_ENABLE, 2);
@@ -305,7 +305,7 @@
reg::ClearBits(g_apb_misc_regs + PINMUX_AUX_LCD_BL_EN, reg::EncodeMask(PINMUX_REG_BITS_MASK(AUX_TRISTATE)));
reg::ClearBits(g_apb_misc_regs + PINMUX_AUX_LCD_RST, reg::EncodeMask(PINMUX_REG_BITS_MASK(AUX_TRISTATE)));
- if (hw_type == spl::HardwareType::_Five_) {
+ if (hw_type == spl::HardwareType::Aula) {
/* Configure LCD backlight. */
reg::SetBits(g_gpio_regs + GPIO_PORT6_CNF_1, 0x4);
reg::SetBits(g_gpio_regs + GPIO_PORT6_OE_1, 0x4);
@@ -358,7 +358,7 @@
reg::SetBits(g_gpio_regs + GPIO_PORT6_OUT_1, 0x4);
os::SleepThread(TimeSpan::FromMilliSeconds(60));
- if (hw_type == spl::HardwareType::_Five_) {
+ if (hw_type == spl::HardwareType::Aula) {
reg::Write(g_dsi_regs + sizeof(u32) * DSI_BTA_TIMING, 0x40103);
} else {
reg::Write(g_dsi_regs + sizeof(u32) * DSI_BTA_TIMING, 0x50204);
@@ -512,7 +512,7 @@
/* Enable backlight. */
if (g_lcd_vendor == 0x2050) {
- EnableBacklightForVendor2050ForHardwareTypeFive(g_display_brightness);
+ EnableBacklightForVendor2050ForAula(g_display_brightness);
} else {
EnableBacklightForGeneric(g_display_brightness);
}
@@ -525,7 +525,7 @@
/* Disable backlight. */
if (g_lcd_vendor == 0x2050) {
- EnableBacklightForVendor2050ForHardwareTypeFive(0);
+ EnableBacklightForVendor2050ForAula(0);
} else {
pwm::driver::SetEnabled(g_lcd_backlight_session, false);
pwm::driver::CloseSession(g_lcd_backlight_session);
diff --git a/exosphere/program/source/secmon_setup.cpp b/exosphere/program/source/secmon_setup.cpp
index 5eabdbd..875c296 100644
--- a/exosphere/program/source/secmon_setup.cpp
+++ b/exosphere/program/source/secmon_setup.cpp
@@ -409,8 +409,8 @@
reg0 |= reg::Encode(SLAVE_SECURITY_REG_BITS_ENUM(0, CEC, ENABLE));
}
- /* Icosa, Iowa, and Five all set I2C4 to be secure. */
- if (hw_type == fuse::HardwareType_Icosa && hw_type == fuse::HardwareType_Iowa && hw_type == fuse::HardwareType_Five) {
+ /* Icosa, Iowa, and Aula all set I2C4 to be secure. */
+ if (hw_type == fuse::HardwareType_Icosa && hw_type == fuse::HardwareType_Iowa && hw_type == fuse::HardwareType_Aula) {
reg1 |= reg::Encode(SLAVE_SECURITY_REG_BITS_ENUM(1, I2C4, ENABLE));
}